@@ -14,9 +14,4 @@ sub _build_out {
     return $exporter;
 }
 
-sub add {
-    my ($self, $item) = @_;
-    $self->out->add($item);
-}
-
-1;
+1;
\ No newline at end of file
